import {Injectable} from '@angular/core';
import {HttpClient} from '@angular/common/http';
import {Observable, of} from "rxjs";
import {COOKIE, User} from "../login/utils/helper.class";
import {catchError, map} from "rxjs/operators";

@Injectable({
  providedIn: 'root'
})
export class UserManagementService {

  constructor(private http: HttpClient) {
  }

  public getUserInfo(url: string): Observable<User> {
    const token = COOKIE.getCookie('AccessToken');
    return this.http.get<User>(url + token).pipe(map(userInfo => {
      return this.parseUserInfo(userInfo);
    })).pipe(catchError(() => {
      return of(null);
    }));
  }

  private parseUserInfo(info: any) {
    const user: User = new User();
    user.id = (info.sub && info.sub.indexOf('@')) ? info.sub.substring(0, info.sub.indexOf('@')) : info.sub;

    user.firstname = (info.given_name) ? info.given_name : "";
    user.lastname = (info.family_name) ? info.family_name : "";
    user.email = info.email;
    user.fullname = (info.name) ? info.name : "";
    if (user.fullname == "") {
      if (user.firstname != "") {
        user.fullname += user.firstname;
      }
      if (user.lastname != "") {
        user.fullname += user.lastname;
      }
      if (user.fullname == "") { //fullname is still empty set a default
        user.fullname = "Anonymous user";
      }
    }
    if (info.edu_person_entitlements) {
      user.role = info.edu_person_entitlements;
    } else {
      user.role = [];
    }
    user.expirationDate = info.exp;
    return user;
  }
}
